/// <reference types="express" />
/// <reference types="node" />
import { Discovery } from './discovery/Discovery';
import { Logger } from './shared/Logger';
import { SyncedRealm } from "./shared/SyncedRealm";
import { RealmDefinition } from "./realms";
import * as Express from 'express';
import * as http from 'http';
export declare class ServerConfiguration {
    serverId?: string;
    hostname?: string;
    port?: number;
    agreement?: string | {
        name: string;
        email: string;
    };
    logLevel?: string;
    logPath?: string;
    logger?: Logger;
    discovery?: Discovery;
    dataPath?: string;
    privateKeyPath?: string;
    publicKeyPath?: string;
    autoKeyGen?: boolean;
}
export declare class Server {
    config: ServerConfiguration;
    services: any[];
    discovery: Discovery;
    logger: Logger;
    privateKey: string;
    publicKey: string;
    adminToken: string;
    readonly version: string;
    private _started;
    readonly started: boolean;
    readonly expressApp: Express.Application;
    readonly httpServer: http.Server;
    constructor(config?: ServerConfiguration);
    useMiddleware(...args: any[]): Server;
    start(): Promise<void>;
    readonly address: string;
    shutdown(): Promise<void>;
    addServices(...services: any[]): this;
    addService(service: any | string, config?: object): this;
    removeService(service: any | string): this;
    private syncedRealms;
    getSyncedRealm(def: RealmDefinition): SyncedRealm;
    private registerSyncedRealm(remotePath, syncedRealm);
    closeSyncedRealm(remotePath: string): void;
    private upgradeHandler(req, socket, head);
    private injectLogger();
    private addServiceEndpoints();
    private startServices();
    private stopServices();
    private registerServices();
    private deregisterServices();
    private authenticationMiddleware(req, res, next);
    private processException(error);
    private errorHandler(error, req, res, next);
}
